UserContextProvider constructor

UserContextProvider({
  1. String? id,
  2. String? email,
  3. String? role,
  4. String? tenantId,
  5. Map<String, dynamic> traits = const {},
  6. bool manualOnly = false,
})

Creates a user context provider that exposes lightweight identifiers and traits, optionally limiting collection to manual reports.

Implementation

UserContextProvider({
  this.id,
  this.email,
  this.role,
  this.tenantId,
  Map<String, dynamic> traits = const {},
  bool manualOnly = false,
})  : _traits = Map<String, dynamic>.from(traits),
      _manualOnly = manualOnly;