clearCache method
void
clearCache()
Clears the cached value, forcing the next call to hit collect.
Implementation
void clearCache() {
_cacheCell.value = null;
_timestampCell.value = null;
}
Clears the cached value, forcing the next call to hit collect.
void clearCache() {
_cacheCell.value = null;
_timestampCell.value = null;
}