instance property
Global singleton used across the app to coordinate reporting.
Implementation
static final BugReportClient instance = BugReportClient._();
Global singleton used across the app to coordinate reporting.
static final BugReportClient instance = BugReportClient._();