DedupeStrategy class

Dedupe policy (time-windowed, fingerprint-based).

Constructors

DedupeStrategy.windowed([Duration window = const Duration(seconds: 60)])
Creates a dedupe strategy that treats events as duplicates within window.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
window Duration
The period during which events with the same fingerprint are dropped.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited