ErrorSeverity typedef
ErrorSeverity = Severity
Backwards compatible alias for older code that referenced ErrorSeverity.
Implementation
typedef ErrorSeverity = Severity;
Backwards compatible alias for older code that referenced ErrorSeverity.
typedef ErrorSeverity = Severity;