RateLimit class

Rate limit policy (windowed).

Constructors

RateLimit(int maxEvents, Duration per)
Creates a rate limit that permits maxEvents per per duration window.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxEvents int
Maximum number of events allowed within the window.
final
per Duration
Duration that bounds the rate-limit window.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited