Attachment class

Lightweight attachment descriptor (payload sourcing is implementation-defined).

Constructors

Attachment({required String name, required String contentType})
Creates an attachment descriptor with a display name and contentType.
const
Attachment.fromMap(Map<String, dynamic> map)
Rehydrates an attachment from a serialized map.
factory

Properties

contentType String
Mime type describing the attachment payload.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Human-readable attachment name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes the attachment to a JSON-friendly map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited