toString method

  1. @override
String toString()

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final buf = StringBuffer()
    ..writeln('$runtimeType')
    ..writeln('  userMessage: $userMessage')
    ..writeln('  devMessage : $devMessage')
    ..writeln('  severity   : $severity')
    ..writeln('  reportable : $isReportable');
  if (metadata.isNotEmpty) {
    buf.writeln('  metadata   : $metadata');
  }
  if (cause != null) {
    buf.writeln('  cause      : ${cause.runtimeType}: $cause');
  }
  if (stack != null) {
    buf.writeln('  stack      :\n$stack');
  }
  return buf.toString().trimRight();
}