ComponentNotInitializedException class

Thrown when a required component is used before being initialized.

Inheritance
Annotations

Constructors

ComponentNotInitializedException({required String component, Object? cause, StackTrace? stack, Map<String, dynamic> metadata = const {}, bool isReportable = true})
Creates an exception indicating the referenced component has not been initialized.

Properties

cause Object?
Original underlying error, if any.
finalinherited
devMessage String
Developer-friendly details, safe for logs and tools.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isReportable bool
Whether this exception should be reported automatically.
finalinherited
metadata Map<String, dynamic>
Additional diagnostic data related to this exception.
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity Severity
How serious this exception is.
finalinherited
stack StackTrace?
Capture location. Defaults to StackTrace.current when not provided.
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
userMessage String
Human-friendly text appropriate for end-users.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited