statusDevMessage property
Returns the developer-friendly HTTP status message associated with the number. If the status code is not found, it returns "Not Found".
Implementation
final String statusDevMessage;
Returns the developer-friendly HTTP status message associated with the number. If the status code is not found, it returns "Not Found".
final String statusDevMessage;