statusMessages property
Returns the HTTP status message associated with the number. If the status code is not found, it returns "Not Found".
Implementation
final String statusMessages;
Returns the HTTP status message associated with the number. If the status code is not found, it returns "Not Found".
final String statusMessages;