statusUserMessage property
Returns the user-friendly HTTP status message associated with the number. If the status code is not found, it returns "Not Found".
Implementation
final String statusUserMessage;
Returns the user-friendly HTTP status message associated with the number. If the status code is not found, it returns "Not Found".
final String statusUserMessage;