FilterChain class

Compose multiple filters in order (left to right).

Implemented types

Constructors

FilterChain(List<DataFilter> filters)
Creates a filter chain that runs filters sequentially.

Properties

filters List<DataFilter>
Filters that will process the data in sequence.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(Map<String, Object?> input) Map<String, Object?>
Returns a new filtered map. The input map is never mutated.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited