enableContentBasedDetection property

bool enableContentBasedDetection
final

If true, values that look like secrets are masked even if their keys are not sensitive (e.g., raw tokens in arrays).

Implementation

final bool enableContentBasedDetection;