SensitiveFieldMatcher class

Matches sensitive keys and/or path segments.

Constructors

SensitiveFieldMatcher({Set<String>? extraKeys})
Creates a matcher with optional extraKeys to extend the defaults.

Properties

hashCode int
The hash code for this object.
no setterinherited
keys Set<String>
Case-insensitive key names that should be masked.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(String key) bool
Returns true if the immediate key is sensitive.
matchesAny(Iterable<String> pathSegments) bool
Returns true if any path segment is sensitive.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited