DedupeStrategy class
Dedupe policy (time-windowed, fingerprint-based).
Constructors
- DedupeStrategy.windowed([Duration window = const Duration(seconds: 60)])
-
Creates a dedupe strategy that treats events as duplicates within
window.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited