PermissionException class
Permission-related failures (camera, location, notifications, etc.).
- Inheritance
-
- Object
- BaseException
- PermissionException
- Annotations
Constructors
-
PermissionException({required String permission, required PermissionStatus status, String? userMessage, String? devMessage, Object? cause, StackTrace? stack, Map<
String, dynamic> metadata = const {}, bool isReportable = false}) -
Creates a permission exception describing the failed
permissionandstatus.
Properties
- cause → Object?
-
Original underlying error, if any.
finalinherited
- devMessage → String
-
Developer-friendly details, safe for logs and tools.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReportable → bool
-
Whether this exception should be reported automatically.
finalinherited
-
metadata
→ Map<
String, dynamic> -
Additional diagnostic data related to this exception.
finalinherited
- permission → String
-
Identifier describing the missing permission (e.g. "camera").
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → Severity
-
How serious this exception is.
finalinherited
- stack → StackTrace?
-
Capture location. Defaults to StackTrace.current when not provided.
finalinherited
- status → PermissionStatus
-
Normalized permission status.
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - userMessage → String
-
Human-friendly text appropriate for end-users.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited