MediaException class
Media-specific operation failures (pick/upload/download/process).
- Inheritance
-
- Object
- BaseException
- PlatformOperationException
- MediaException
- Annotations
Constructors
- MediaException({required MediaOperationType type, required String mediaType, String? path, String? mimeType, int? fileSize, String? code, dynamic details, Object? cause, StackTrace? stack, bool isRetryable = true, bool isReportable = true})
-
Creates a media exception scoped to the given
typeandmediaType.
Properties
- cause → Object?
-
Original underlying error, if any.
finalinherited
- code → String?
-
Platform-specific error code, when provided by the channel.
finalinherited
- details → dynamic
-
Additional details supplied by the platform.
finalinherited
- devMessage → String
-
Developer-friendly details, safe for logs and tools.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPermissionError → bool
-
Indicates whether the platform error stems from a permission issue.
no setterinherited
- isReportable → bool
-
Whether this exception should be reported automatically.
finalinherited
- isTimeout → bool
-
Indicates whether the platform error represents a timeout.
no setterinherited
- mediaType → String
-
Category of media that was being processed (e.g.
image).final -
metadata
→ Map<
String, dynamic> -
Additional diagnostic data related to this exception.
finalinherited
- operation → String
-
Logical operation name (e.g., "camera_capture").
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → Severity
-
How serious this exception is.
finalinherited
- stack → StackTrace?
-
Capture location. Defaults to StackTrace.current when not provided.
finalinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - userMessage → String
-
Human-friendly text appropriate for end-users.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited