CacheException class
Cache-layer storage failures.
- Inheritance
-
- Object
- BaseException
- StorageException
- CacheException
- Annotations
Constructors
-
CacheException({required String key, required String operation, Object? cause, StackTrace? stack, Map<
String, dynamic> metadata = const {}}) - Creates a cache exception for failures interacting with in-memory/disk cache.
Properties
- cause → Object?
-
Original underlying error, if any.
finalinherited
- devMessage → String
-
Developer-friendly details, safe for logs and tools.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReportable → bool
-
Whether this exception should be reported automatically.
finalinherited
- key → String?
-
Storage key involved in the failure.
finalinherited
-
metadata
→ Map<
String, dynamic> -
Additional diagnostic data related to this exception.
finalinherited
- operation → String
-
Operation that failed (e.g.,
read,write).finalinherited -
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → Severity
-
How serious this exception is.
finalinherited
- stack → StackTrace?
-
Capture location. Defaults to StackTrace.current when not provided.
finalinherited
- storageType → String?
-
Storage backend type (cache, secure storage, etc.).
finalinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - userMessage → String
-
Human-friendly text appropriate for end-users.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited