FilterSanitizer class
Bridge to apply a DataFilter as a Sanitizer.
- Implemented types
- Available extensions
Constructors
- FilterSanitizer(DataFilter filter)
- Wraps a DataFilter so it can be used as a sanitizer in pipelines.
Properties
- filter → DataFilter
-
Underlying filter invoked during sanitization.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sanitize(
Map< String, dynamic> data) → Map<String, dynamic> -
Returns a new sanitized map. The input is never mutated.
override
-
sanitizeEvent(
ReportEvent event) → ReportEvent -
Available on Sanitizer, provided by the ReportEventSanitizer extension
Returns a copy ofeventwith the sanitized payload embedded. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited