RegexValueSanitizer class
Rewrites any string values that match a given regex to a replacement. Useful for emails/phones if you want to aggressively strip PII.
- Implemented types
- Available extensions
Constructors
-
RegexValueSanitizer(Map<
RegExp, String> rules) -
Creates a regex-based sanitizer with replacement
rules.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sanitize(
Map< String, dynamic> data) → Map<String, dynamic> -
Returns a new sanitized map. The input is never mutated.
override
-
sanitizeEvent(
ReportEvent event) → ReportEvent -
Available on Sanitizer, provided by the ReportEventSanitizer extension
Returns a copy ofeventwith the sanitized payload embedded. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited