SanitizerChain class
Compose sanitizers in order.
- Implemented types
- Available extensions
Constructors
-
SanitizerChain(List<
Sanitizer> sanitizers) -
Creates a sanitizer chain that applies
sanitizerssequentially.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sanitizers
→ List<
Sanitizer> -
Sanitizers executed in sequence.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sanitize(
Map< String, dynamic> data) → Map<String, dynamic> -
Returns a new sanitized map. The input is never mutated.
override
-
sanitizeEvent(
ReportEvent event) → ReportEvent -
Available on Sanitizer, provided by the ReportEventSanitizer extension
Returns a copy ofeventwith the sanitized payload embedded. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited